Rustling
Rustling is a blazingly fast library for computational linguistics. It is written in Rust, with Python bindings.
Rustling is fully functional for both Rust-only and Python-only users. The objects defined and exposed in Rust correspond to the same ones in Python under the comparable namespace. For documentation, especially details about linguistics and modeling, please see the Python docs: https://rustling.readthedocs.io
Modules
- chat
- CHAT parsing.
- hmm
- Hidden Markov Model.
- lm
- Language models.
- ngram
- N-gram counting.
- perceptron_
pos_ tagger - POS tagging.
- persistence
- seq_
feature - Configurable feature templates for sequence labeling models.
- trie
- Trie (prefix tree) data structure for efficient sequence matching.
- wordseg
- Word segmentation models.